/*	Buzzer.h
*
*	Buzzer output using Timer/Counter 0 for frequency control.
*
*	NOTE: this code...
*	- uses Timer/Counter 0
*	- assumes internal clock is running at 8MHz
*
*	Written by Cathy Saxton
*	robotics@idleloop.com
*/

#pragma once

#include "Util.h"
#include "InOut.h"

/* "tones" for the buzzer; passed to the Buzz function;
   note: keep in sync with mptonecOverflow array in Buzzer.cpp */
enum
{
	toneMin = 0,
	toneHigh = toneMin,	// high-pitched buzz
	toneMid,			// mid-pitched buzz
	toneLow,			// low-pitched buzz
	toneMax
};

class BUZZER
{
public:
	/* constructor for specifying the output port of the buzzer;
	   note that only one port can be active at a time! */
	BUZZER(OUT *pout);

	/* sound the buzzer for the specified number of milliseconds;
	   this happens as a background task -- this function will return
	   almost immediately so other code can be executed while the buzz
	   occurs; the "tone" parameter should be one of the tone
	   values in the enum[eration] above (toneHigh, toneMid, toneLow);
	   note: if the buzzer is already on, this will change it, not
	   wait until the previous request completes! */
	void Buzz(uchar tone, uint ms) const;
};
