/*	Motor.h
*
*	Motor control via H-bridge IC and PWM using Timer/Counter 1.
*
*	Written by Cathy Saxton
*	robotics@idleloop.com
*/

#pragma once

#include "InOut.h"

class MOTOR
{
public:
	/* constructor for specifying the output ports
	   for the PWM and direction of a motor;
	   NOTE: PWM must be PB1 or PB2 (OCR1A/B) */
	MOTOR(OUT *poutPWM, OUT *poutDir);

	/* sets motor speed:
	   -255 = full speed backward
	      0 = stop
	    255 = full speed forward
	*/
	void SetSpeed(int pwm) const;

private:
	static void Init();
	
	OUT *m_poutDir;
	unsigned char m_shCom;
	volatile uint8_t *m_pregOCR1xL;

	/* static variable: one per class, not instance */
	static bool s_fInit;
};
